@@ -26,21 +26,21 @@ class AnyOfValidatorTest:
     @staticmethod
     def test_string_values_valid():
         """ Test AnyOfValidator with string value list with valid input. """
-        validator = AnyOfValidator(['red apple', 'green apple', 'strawberry'])
+        validator = AnyOfValidator(['red apple', 'green apple', 'STRAWBERRY'])
         assert validator.validate('red apple') == 'red apple'
         assert validator.validate('green apple') == 'green apple'
-        assert validator.validate('strawberry') == 'strawberry'
+        assert validator.validate('strawberry') == 'STRAWBERRY'
 
     @staticmethod
-    @pytest.mark.parametrize('input_data', ['', 'bananana', 'red', 'STRAWBERRY'])
+    @pytest.mark.parametrize('input_data', ['', 'bananana', 'red'])
     def test_string_values_invalid_value(input_data):
         """ Test AnyOfValidator with string value list with invalid input. """
-        validator = AnyOfValidator(['red apple', 'green apple', 'strawberry'])
+        validator = AnyOfValidator(['red apple', 'green apple', 'STRAWBERRY'])
         with pytest.raises(ValueNotAllowedError) as exception_info:
             validator.validate(input_data)
         assert exception_info.value.to_dict() == {
             'code': 'value_not_allowed',
-            'allowed_values': ['red apple', 'green apple', 'strawberry'],
+            'allowed_values': ['red apple', 'green apple', 'STRAWBERRY'],
         }
 
     @staticmethod
@@ -98,11 +98,12 @@ class AnyOfValidatorTest:
         """ Test AnyOfValidator with allowed values of mixed types with valid input. """
         validator = AnyOfValidator(allowed_values=('strawberry', 42, None))
         assert validator.validate('strawberry') == 'strawberry'
+        assert validator.validate('STRAWBERRY') == 'strawberry'
         assert validator.validate(42) == 42
         assert validator.validate(None) is None
 
     @staticmethod
-    @pytest.mark.parametrize('input_data', [0, 13, '', 'banana', 'STRAWBERRY'])
+    @pytest.mark.parametrize('input_data', [0, 13, '', 'banana'])
     def test_mixed_values_invalid_value(input_data):
         """ Test AnyOfValidator with allowed values of mixed types with invalid input. """
         validator = AnyOfValidator(allowed_values=('strawberry', 42, None))
@@ -181,46 +182,60 @@ class AnyOfValidatorTest:
                 **expected_type_dict,
             }
 
-    # Test AnyOfValidator with case-insensitive option
+    @staticmethod
+    def test_empty_allowed_values_with_allowed_types():
+        """ Test AnyOfValidator with an empty list of allowed values (requires explicit allowed_types). """
+        validator = AnyOfValidator([], allowed_types=[str])
+
+        # There can't be any valid input for this validator (in that way it acts like a RejectValidator with a different error)
+        with pytest.raises(ValueNotAllowedError) as exception_info:
+            validator.validate('banana')
+        assert exception_info.value.to_dict() == {
+            'code': 'value_not_allowed',
+            'allowed_values': [],
+        }
+
+    # Test AnyOfValidator with case-sensitive option
 
     @staticmethod
     @pytest.mark.parametrize(
-        'case_insensitive, input_data, expected_result',
+        'case_sensitive, input_data, expected_result',
         [
             # Case-sensitive matching
-            (False, 'Strawberry', 'Strawberry'),
-            (False, 42, 42),
-
-            # Case-insensitive matching
             (True, 'Strawberry', 'Strawberry'),
-            (True, 'STRAWBERRY', 'Strawberry'),
-            (True, 'strawberry', 'Strawberry'),
             (True, 42, 42),
+
+            # Case-insensitive matching (default)
+            (False, 'Strawberry', 'Strawberry'),
+            (False, 'STRAWBERRY', 'Strawberry'),
+            (False, 'strawberry', 'Strawberry'),
+            (False, 42, 42),
         ]
     )
-    def test_case_insensitive_valid(case_insensitive, input_data, expected_result):
+    def test_case_sensitive_valid(case_sensitive, input_data, expected_result):
         """ Test AnyOfValidator with case-sensitive and case-insensitive string matching, valid input. """
-        validator = AnyOfValidator(allowed_values=['Strawberry', 42], case_insensitive=case_insensitive)
+        validator = AnyOfValidator(allowed_values=['Strawberry', 42], case_sensitive=case_sensitive)
         assert validator.validate(input_data) == expected_result
 
     @staticmethod
     @pytest.mark.parametrize(
-        'case_insensitive, input_data',
+        'case_sensitive, input_data',
         [
             # Case-sensitive matching
-            (False, 'strawberry'),
-            (False, 'banana'),
-            (False, 13),
-
-            # Case-insensitive matching
-            (True, 'straw_berry'),
+            (True, 'strawberry'),
+            (True, 'STRAWBERRY'),
             (True, 'banana'),
             (True, 13),
+
+            # Case-insensitive matching (default)
+            (False, 'straw_berry'),
+            (False, 'banana'),
+            (False, 13),
         ]
     )
-    def test_case_insensitive_invalid(case_insensitive, input_data):
+    def test_case_sensitive_invalid(case_sensitive, input_data):
         """ Test AnyOfValidator with case-sensitive and case-insensitive string matching, invalid input. """
-        validator = AnyOfValidator(allowed_values=['Strawberry', 42], case_insensitive=case_insensitive)
+        validator = AnyOfValidator(allowed_values=['Strawberry', 42], case_sensitive=case_sensitive)
         with pytest.raises(ValueNotAllowedError) as exception_info:
             validator.validate(input_data)
         assert exception_info.value.to_dict() == {
@@ -228,6 +243,36 @@ class AnyOfValidatorTest:
             'allowed_values': ['Strawberry', 42],
         }
 
+    @staticmethod
+    @pytest.mark.parametrize(
+        'case_insensitive, valid_input, invalid_input',
+        [
+            # Case-insensitive matching
+            (True, ['Strawberry', 'strawberry', 'STRAWBERRY'], ['banana']),
+
+            # Case-sensitive matching
+            (False, ['Strawberry'], ['strawberry', 'STRAWBERRY', 'banana']),
+        ]
+    )
+    def test_deprecated_case_insensitive(case_insensitive, valid_input, invalid_input):
+        """ Test AnyOfValidator with deprecated case_insensitive parameter, which should issue a deprecation warning. """
+        with pytest.deprecated_call():
+            # This should issue a DeprecationWarning for the case_insensitive parameter, but continue without problems
+            validator = AnyOfValidator(allowed_values=['Strawberry'], case_insensitive=case_insensitive)
+
+        # Valid input
+        for input_data in valid_input:
+            assert validator.validate(input_data) == 'Strawberry'
+
+        # Invalid input
+        for input_data in invalid_input:
+            with pytest.raises(ValueNotAllowedError) as exception_info:
+                validator.validate(input_data)
+            assert exception_info.value.to_dict() == {
+                'code': 'value_not_allowed',
+                'allowed_values': ['Strawberry'],
+            }
+
     # Tests for validation errors
 
     @staticmethod
@@ -248,9 +293,33 @@ class AnyOfValidatorTest:
 
     # Invalid validator parameters
 
+    @staticmethod
+    def test_empty_allowed_values_requires_allowed_types():
+        """ Test that AnyOfValidator raises exception when allowed_values is empty and no allowed_types are specified. """
+        with pytest.raises(InvalidValidatorOptionException) as exception_info:
+            AnyOfValidator([])
+        assert str(exception_info.value) == 'Parameter "allowed_types" is an empty list (or types could not be autodetermined).'
+
     @staticmethod
     def test_empty_allowed_types():
-        """ Check that AnyOfValidator raises exception when allowed_types is empty. """
+        """ Test that AnyOfValidator raises exception when allowed_types is empty. """
         with pytest.raises(InvalidValidatorOptionException) as exception_info:
             AnyOfValidator([1, 2, 3], allowed_types=[])
         assert str(exception_info.value) == 'Parameter "allowed_types" is an empty list (or types could not be autodetermined).'
+
+    @staticmethod
+    @pytest.mark.parametrize(
+        'case_sensitive, case_insensitive',
+        [
+            (True, True),
+            (True, False),
+            (False, True),
+            (False, False),
+        ]
+    )
+    def test_case_insensitive_parameter_mutually_exclusive(case_sensitive, case_insensitive):
+        """ Test that the parameters "case_sensitive" and "case_insensitive" (deprecated) cannot be set at the same time. """
+        with pytest.raises(InvalidValidatorOptionException) as exception_info:
+            AnyOfValidator(['banana'], case_sensitive=case_sensitive, case_insensitive=case_insensitive)
+        assert str(exception_info.value) == \
+               'Parameters "case_sensitive" and "case_insensitive" (now deprecated) are mutually exclusive.'
